/*!
 ******************************************************************************
 *
 * \file
 *
 * \brief   Header file containing RAJA Dispatcher and WorkRunner constructs.
 *
 ******************************************************************************
 */

//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
// Copyright (c) 2016-25, Lawrence Livermore National Security, LLC
// and RAJA project contributors. See the RAJA/LICENSE file for details.
//
// SPDX-License-Identifier: (BSD-3-Clause)
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//

#ifndef RAJA_openmp_WorkGroup_HPP
#define RAJA_openmp_WorkGroup_HPP

#include "RAJA/policy/openmp/WorkGroup/Dispatcher.hpp"
#include "RAJA/policy/openmp/WorkGroup/WorkRunner.hpp"

#endif  // closing endif for header file include guard
